/**
 * Get device information.
 * - Effective connection type: https://developer.mozilla.org/en-US/docs/Web/API/NetworkInformation
 * - Device memory in GB rounded to 2: https://developer.mozilla.org/en-US/docs/Web/API/Navigator/deviceMemory
 *
 * @return {{ url?: string, userAgent?: string, deviceType?: DeviceType, deviceMemory?: number, effectiveConnectionType?: EffectiveConnectionType, hardwareConcurrency?: number }}
 */
export function getDeviceInfo(): {
    url?: string | undefined;
    userAgent?: string | undefined;
    deviceType?: "phone" | "tablet" | "desktop" | undefined;
    deviceMemory?: number | undefined;
    effectiveConnectionType?: "slow-2g" | "2g" | "3g" | "4g" | undefined;
    hardwareConcurrency?: number | undefined;
};
/**
 * Get effective connection type.
 * https://developer.mozilla.org/en-US/docs/Web/API/NetworkInformation
 *
 * @return {EffectiveConnectionType | undefined}
 */
export function getEffectiveConnectionType(): "slow-2g" | "2g" | "3g" | "4g" | undefined;
/**
 * Get device memory in GB rounded to 2.
 * https://developer.mozilla.org/en-US/docs/Web/API/Navigator/deviceMemory
 *
 * @return {number | undefined}
 */
export function getDeviceMemory(): number | undefined;
/**
 * Get CPU cores.
 *
 * @return {number | undefined}
 */
export function getHardwareConcurrency(): number | undefined;
/**
 * Get current url.
 *
 * @return {string | undefined}
 */
export function getUrl(): string | undefined;
/**
 * Get user-agent header.
 *
 * @return {string | undefined}
 */
export function getUserAgent(): string | undefined;
/**
 * Get device type.
 * based on https://github.com/matthewhudson/current-device/blob/master/src/index.js
 *
 * @return {DeviceType | undefined}
 */
export function getDeviceType(): "phone" | "tablet" | "desktop" | undefined;
export type EffectiveConnectionType = "slow-2g" | "2g" | "3g" | "4g";
export type DeviceType = "phone" | "tablet" | "desktop";
export type NetworkInformation = {
    effectiveType: "slow-2g" | "2g" | "3g" | "4g";
};
