"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
/** @typedef {(metrics: { timeToFirstByte: number, domContentLoaded: number, load: number, serverTiming: object[] } | null) => any} NavigationCallback */
/**
 * Resolve with navigation arguments.
 *
 * @param {NavigationCallback} cb
 */
function onNavigation(cb) {
    if (!utils_1.perf || !utils_1.perf.timing)
        return cb(null);
    if (document.readyState != 'complete') {
        return addEventListener('load', function loadListener() {
            removeEventListener('load', loadListener, true);
            utils_1.raf(resolveNavigationTimingMetrics);
        }, true);
    }
    utils_1.raf(resolveNavigationTimingMetrics); // resolve async
    function resolveNavigationTimingMetrics() {
        if (!utils_1.perf || !utils_1.perf.timing)
            return cb(null);
        const nt = utils_1.perf.timing;
        const navStart = nt.navigationStart;
        const [nav] = utils_1.perf.getEntriesByType('navigation');
        cb({
            timeToFirstByte: utils_1.round(nt.responseStart - navStart),
            domContentLoaded: utils_1.round(nt.domContentLoadedEventEnd - navStart),
            load: utils_1.round(nt.loadEventEnd - navStart),
            serverTiming: nav ? nav.serverTiming : []
        });
    }
}
exports.onNavigation = onNavigation;
