/**
 * Observer multiple metrics.
 *
 * @param {Array<EntryType | EntryOpts>} entriesOpts
 * @param {EntriesCallback} callback
 */
export function observeEntries(entriesOpts: ("navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task" | "first-contentful-paint" | {
    type: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task" | "first-contentful-paint";
    buffered?: boolean | undefined;
    filter?: ((entry: PerformanceEntry) => any) | undefined;
    map?: ((entry: PerformanceEntry) => any) | undefined;
})[], callback: (entries: PerformanceEntry[], observer: PerformanceObserver) => any): void;
/**
 * Create performance observer.
 *
 * @param {EntryType | EntryOpts} entryType
 * @param {EntriesCallback} callback
 * @return {PerformanceObserver}
 */
export function createPerformanceObserver(entryType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task" | "first-contentful-paint" | {
    type: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task" | "first-contentful-paint";
    buffered?: boolean | undefined;
    filter?: ((entry: PerformanceEntry) => any) | undefined;
    map?: ((entry: PerformanceEntry) => any) | undefined;
}, callback: (entries: PerformanceEntry[], observer: PerformanceObserver) => any): PerformanceObserver;
/**
 * Get buffered entries by `type`.
 *
 * @param {EntryType} entryType
 * @return {Promise<PerformanceEntry[]>}
 */
export function getEntriesByType(entryType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task" | "first-contentful-paint"): Promise<PerformanceEntry[]>;
export type EntriesCallback = (entries: PerformanceEntry[], observer: PerformanceObserver) => any;
export type EntryCallback = (entry: PerformanceEntry) => any;
export type StrictEntryType = "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource";
export type EntryType = "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task" | "first-contentful-paint";
export type EntryOpts = {
    type: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task" | "first-contentful-paint";
    buffered?: boolean | undefined;
    filter?: ((entry: PerformanceEntry) => any) | undefined;
    map?: ((entry: PerformanceEntry) => any) | undefined;
};
